/**
 * @file
 * Init tarteaucitron.js script.
 */

(function(Drupal, drupalSettings, tarteaucitron) {
  /**
   * Init tarteaucitron.js script.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attaches the script.
   */
  Drupal.behaviors.tacjs = {
    attach: function attach() {
      // Add custom texts to tarteaucitron.
      tarteaucitronCustomText = drupalSettings.tacjs.texts;

      // Set expiration time in day(s)
      if (drupalSettings.tacjs.expire) {
        window.tarteaucitronExpireInDay = true;
        window.tarteaucitronForceExpire = drupalSettings.tacjs.expire;
      }

      if (drupalSettings.tacjs.user) {
        // Workaround for #3120915: convert multiplegtagUa into a Array
        // See https://github.com/AmauriC/tarteaucitron.js/pull/394
        if (drupalSettings.tacjs.user.multiplegtagUa && typeof drupalSettings.tacjs.user.multiplegtagUa === "string")
          drupalSettings.tacjs.user.multiplegtagUa = drupalSettings.tacjs.user.multiplegtagUa.split(", ");

        // Workaround for #3204238: convert googleFonts into a Array
        // See https://www.drupal.org/project/tacjs/issues/3204238
        if (drupalSettings.tacjs.user.googleFonts && typeof drupalSettings.tacjs.user.googleFonts === "string")
          drupalSettings.tacjs.user.googleFonts = drupalSettings.tacjs.user.googleFonts.split(", ");

        // Add consent to tarteaucitron services.
        Object.keys(drupalSettings.tacjs.services)
          .forEach(function(service) {
            if (drupalSettings.tacjs.services[service].needConsent) {
              tarteaucitron.services[service].needConsent = drupalSettings.tacjs.services[service].needConsent;
            }
          });

        // Add users identification to tarteaucitron.
        tarteaucitron.user = drupalSettings.tacjs.user;
      }

      // Add enabled services to tarteaucitron services.
      Object.keys(drupalSettings.tacjs.services)
        .filter(function(service) {
          // Filter enabled services.
          return drupalSettings.tacjs.services[service].status;
        })
        .forEach(function(service) {
          (tarteaucitron.job = tarteaucitron.job || []).push(service);
        });

      // Initiate tarteaucitron
      tarteaucitron.init(drupalSettings.tacjs.dialog);
    }
  };
})(Drupal, drupalSettings, tarteaucitron);
